The CPHD 1.0 ErrorParameters object
===================================

.. automodule:: sarpy.io.phase_history.cphd1_elements.ErrorParameters
    :members:
    :show-inheritance:
    :inherited-members:
